==> lms-1.8.0rc5.tar.gz: lms/lib/checkip.php <==
<?php

/*
 * LMS version 1.8.0rc5 Rosha
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: checkip.php,v 1.23.2.1 2005/12/07 08:56:19 alec Exp $
 */

// Checking if connection is from allowed IP

if(isset($CONFIG['phpui']['allow_from']))
{
	// delete ipv6 prefix if it's present: 
	
	$ipaddr = str_replace('::ffff:','',$_SERVER['REMOTE_ADDR']);

	$allowedlist = explode(',',$CONFIG['phpui']['allow_from']);

	$isin = FALSE;

	foreach($allowedlist as $value)
	{
		list($net,$mask) = sscanf($value, '%[^/]/%[0-9]');
		$net=trim($net);
		$mask=trim($mask);
		if($mask == '')
			$mask = '32';
		if($mask >= 0 || $mask <= 32)
			$mask = prefix2mask($mask);
	
		if(isipinstrict($ipaddr,$net,$mask))
			$isin = TRUE;
	}

	if(!$isin)
	{
		header('HTTP/1.1 403 Forbidden');
		echo '<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
		<HTML><HEAD>
		<TITLE>403 Forbidden</TITLE>
		</HEAD><BODY>
		<H1>Forbidden</H1>
		You don\'t have permission to access '.$_SERVER['REQUEST_URI'].'
		on this server.<P>
		<HR>
		'.$_SERVER['SERVER_SIGNATURE'].'
		</BODY></HTML>
		';
		exit(0);
	}
}

?>

==> lms-1.10.2.tar.gz: lms/lib/checkip.php <==
<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: checkip.php,v 1.27.2.2 2007/09/28 06:34:24 alec Exp $
 */

// Checking if connection is from allowed IP

if(!empty($CONFIG['phpui']['allow_from']))
{
	// delete ipv6 prefix if it's present: 
	
	$ipaddr = str_replace('::ffff:','',$_SERVER['REMOTE_ADDR']);

	$allowedlist = explode(',',$CONFIG['phpui']['allow_from']);

	$isin = FALSE;

	foreach($allowedlist as $value)
	{
		$net = '';
		$mask = '';
		
		if(strpos($value, '/')===FALSE)
			$net = $value;
		else
			list($net, $mask) = explode('/', $value);
		
		$net = trim($net);
		$mask = trim($mask);

		if($mask == '')
			$mask = '255.255.255.255';
		elseif(is_numeric($mask))
			$mask = prefix2mask($mask);

		if(isipinstrict($ipaddr, $net, $mask))
		{
			$isin = TRUE;
			break;
		}
	}

	if(!$isin)
	{
		header('HTTP/1.1 403 Forbidden');
		echo '<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
		<HTML><HEAD>
		<TITLE>403 Forbidden</TITLE>
		</HEAD><BODY>
		<H1>Forbidden</H1>
		You don\'t have permission to access '.$_SERVER['REQUEST_URI'].'
		on this server.<P>
		<HR>
		'.$_SERVER['SERVER_SIGNATURE'].'
		</BODY></HTML>
		';
		exit(0);
	}
}

?>
